package WebGUI::i18n::English::Asset_Thingy;

our $I18N = {
    'cache timeout' => {
        message => q|Cache Timeout|,
        lastUpdated => 0,
    },

    'cache timeout help' => {
        message => q|Since all users will see this asset the same way, we can cache it for long periods of time to increase performance. How long should we cache it?<br /> <br /><b>UI Level: 8</b>|,
        lastUpdated => 0,
    },

    'assetName' => {
        message => q|Thingy|,
        lastUpdated => 1128830080,
        context => 'Default name of all snippets',
    },

    'template_label' => {
        message => q|Thingy List Template|,
        lastUpdated => 1121703035,
    },

    'add thing label' => {
        message => q|Add Thing|,
        lastUpdated => 1104630516,
    },

    'default thing label' => {
        message => q|Default Thing|,
            lastUpdated => 1104630516,
    },

    'manage things label' => {
        message => q|Manage Things|,
            lastUpdated => 1104630516,
    },

    'delete thing warning' => {
        message => q|Are you sure you want to delete this Thing and all data in it? This is not versioned and can not be undone.|,
        lastUpdated => 1104630516,
    },

    'delete thing data warning' => {
        message => q|Are you sure you want to delete this thing? This is not versioned and cannot be undone.|,
        lastUpdated => 1104630516,
    },
 
    'fields tab label' => {
        message => q|Fields|,
        lastUpdated => 1104630516,
    },

    'edit screen tab label' => {
        message => q|Edit Screen|,
        lastUpdated => 1104630516,
    },

    'view screen tab label' => {
        message => q|View Screen|,
        lastUpdated => 1104630516,
    },

    'search screen tab label' => {
        message => q|Search Screen|,
        lastUpdated => 1104630516,
    },

    'edit thing title' => {
        message => q|Edit/Add Thing|,
        lastUpdated => 1104630516,
    },

    'thing name label' => {
        message => q|Thing Name|,
        lastUpdated => 1104630516,
    },

    'thing name description' => {
        message => q|A human readable name for this thing.|,
        lastUpdated => 1104630516,
    },

    'fields label' => {
        message => q|Fields|,
        lastUpdated => 1104630516,
    },

    'add field label' => {
        message => q|Add Field|,
        lastUpdated => 1104630516,
    },

    'edit screen title label' => {
        message => q|Edit screen title|,
        lastUpdated => 1104630516,
    },

    'edit screen title description' => {
        message => q|The title of the edit screen|,
        lastUpdated => 1104630516,
    },

    'edit instructions label' => {
        message => q|Instructions|,
        lastUpdated => 1104630516,
    },

    'edit instructions description' => {
        message => q|Instructions on the edit screen about adding or editing a thing.|,
        lastUpdated => 1104630516,
    },

    'max entries per user label' => {
        message => q|Max entries per user|,
        lastUpdated => 1223638290,
    },

    'max entries per user description' => {
        message => q|The maximum number of entries a user can add of this thing.|,
        lastUpdated => 1223638290,
    },

    'has entered max per user message' => {
        message => q|You have reached the maximum number of entries.|,
        lastUpdated => 1223638290,
    },

    'who can add label' => {
        message => q|Who can add?|,
        lastUpdated => 1104630516,
    },

    'who can add description' => {
        message => q|The group that can add this thing.|,
        lastUpdated => 1104630516,
    },

    'who can edit label' => {
        message => q|Who can edit?|,
        lastUpdated => 1104630516,
    },

    'who can edit description' => {
        message => q|Select either:<br />- 'owner' if this things data should only be editable by the person who added it
<br />or<br />- a group that can edit all the data in this thing.<br />A user who can edit this Thingy
wobject can always view and edit all data.|,
        lastUpdated => 1223372150,
    },

    'owner' => {
        message => q|Owner|,
        lastUpdated => 1253828331,
        context => q|The person who owns, or submits, or creates a row of data in the Thingy.|
    },

    'save button label label' => {
        message => q|Save Button Label|,
        lastUpdated => 1104630516,
    },

    'default save button label' => {
        message => q|Save|,
        lastUpdated => 1104630516,
    },

    'save button label description' => {
        message => q|The label of the save button on the edit sceen.|,
        lastUpdated => 1104630516,
    },

    'after save label' => {
        message => q|After Save|,
        lastUpdated => 1104630516,
    },

    'search this thing label' => {
        message => q|Search this Thing|,
        lastUpdated => 1104630516,
    },

    'view last edited label' => {
        message => q|View Last Edited/Added|,
        lastUpdated => 1104630516,
    },

    'search other thing label' => {
        message => q|Search Other Thing: |,
        lastUpdated => 1104630516,
    },

    'add other thing label' => {
        message => q|Add Other Thing: |,
        lastUpdated => 1104630516,
    },

    'view thingy default label' => {
        message => q|View Thingy Default|,
        lastUpdated => 1104630516,
    },


    'after save description' => {
        message => q|The screen that is displayed after saving this thing|,
        lastUpdated => 1104630516,
    },

    'edit template label' => {
        message => q|Edit Template|,
        lastUpdated => 1104630516,
    },

    'edit template description' => {
        message => q|edit template is used to display the view screen of this thing.|,
        lastUpdated => 1104630516,
    },

    'on add workflow label' => {
        message => q|On Add|,
        lastUpdated => 1104630516,
    },

    'on add workflow description' => {
        message => q|Workflow that is triggered after adding this thing|,
        lastUpdated => 1104630516,
    },

    'on edit workflow label' => {
        message => q|On Edit|,
        lastUpdated => 1104630516,
    },

    'on edit workflow description' => {
        message => q|Workflow that is triggered after editing this thing|,
        lastUpdated => 1104630516,
    },

    'on delete workflow label' => {
        message => q|On Delete|,
        lastUpdated => 1104630516,
    },

    'on delete workflow description' => {
        message => q|Workflow that is triggered after deleting this thing|,
        lastUpdated => 1104630516,
    },

    'who can view label' => {
        message => q|Who can view?|,
        lastUpdated => 1104630516,
    },

    'who can view description' => {
        message => q|Select either:<br />- 'owner' if this things data should only be viewable by the person who
added it <br />or<br />- a group that can view all the data in this thing.<br />A user who can edit this Thingy
wobject can always view and edit all data.|,
        lastUpdated => 1223372150,
    },

    'view template label' => {
        message => q|View Template|,
        lastUpdated => 1104630516,
    },

    'view template description' => {
        message => q|This template is used to display the view screen of this thing.|,
        lastUpdated => 1104630516,
    },

    'search thing label' => {
        message => q|Search|,
        lastUpdated => 1104630516,
    },

    'default view label' => {
        message => q|Default View|,
        lastUpdated => 1104630516,
    },

    'default view description' => {
        message => q|The default screen for this thing. This can be either the search screen or the add screen.|,
        lastUpdated => 1104630516,
    },

    'display label' => {
        message => q|Display|,
        lastUpdated => 1104630516,
    },

    'view screen title label' => {
        message => q|View Screen Title|,
        lastUpdated => 1104630516,
    },

    'search screen title label' => {
        message => q|Search Screen Title|,
        lastUpdated => 1104630516,
    },

    'search screen title description' => {
        message => q|The title of the search screen|,
        lastUpdated => 1104630516,
    },

    'search description label' => {
        message => q|Description|,
        lastUpdated => 1104630516,
    },

    'search description description' => {
        message => q|Description of the search screen.|,
        lastUpdated => 1104630516,
    },

    'who can search label' => {
        message => q|Who can search?|,
        lastUpdated => 1104630516,
    },

    'who can search description' => {
        message => q|The group that can search this thing.|,
        lastUpdated => 1104630516,
    },

    'who can import label' => {
        message => q|Who can import?|,
        lastUpdated => 1104630516,
    },

    'who can import description' => {
        message => q|The group that can import data into this thing.|,
        lastUpdated => 1104630516,
    },

    'who can export label' => {
        message => q|Who can export?|,
        lastUpdated => 1104630516,
    },

    'who can export description' => {
        message => q|The group that can export this things data.|,
        lastUpdated => 1104630516,
    },

    'export metadata label' => {
        message => q|Export meta data?|,
        lastUpdated => 1223555688,
    },

    'export metadata description' => {
        message => q|Should the export function include the meta data fields like thingDataId, lastUpdated,
ipAddress etc?|,
        lastUpdated => 1223555688,
    },

    'search button label' => {
        message => q|Search|,
        lastUpdated => 1104630516,
    },

    'search template label' => {
        message => q|Search Template|,
        lastUpdated => 1104630516,
    },

    'search template description' => {
        message => q|This template is used to display the search screen of this thing.|,
        lastUpdated => 1104630516,
    },

    'things per page label' => {
        message => q|Things Per Page|,
        lastUpdated => 1104630516,
    },

    'things per page description' => {
        message => q|The number of things that the search screen displays per page.|,
        lastUpdated => 1104630516,
    },

    'sort by label' => {
        message => q|Sort By|,
        lastUpdated => 1104630516,
    },

    'export label' => {
        message => q|Export|,
        lastUpdated => 1104630516,
    },

    'import label' => {
        message => q|Import|,
        lastUpdated => 1104630516,
    },

    'import file label' => {
        message => q|Choose a file to import|,
        lastUpdated => 1104630516,
    },

    'duplicates label' => {
        message => q|What about duplicates?|,
        lastUpdated => 1104630516,
    },

    'ignore first line label' => {
        message => q|Ignore first line?|,
        lastUpdated => 1104630516,
    },

    'skip label' => {
        message => q|Skip|,
        lastUpdated => 1104630516,
    },

    'overwrite label' => {
        message => q|Overwrite|,
        lastUpdated => 1104630516,
    },

    'file contains label' => {
        message => q|File Contains|,
        lastUpdated => 1104630516,
    },

    'check duplicates label' => {
        message => q|Check Duplicates|,
        lastUpdated => 1104630516,
    },

    'field label label' => {
        message => q|Label|,
        lastUpdated => 1031514049
    },

    'field label description' => {
                message => q|The label for this field.|,
                lastUpdated => 1119156590,
        },

    'field type label' => {
        message => q|Field Type|,
        lastUpdated => 1031514049
    },

    'field type description' => {
                message => q|Choose the type of form element for this field. This is also used to validate any input that the user may supply.|,
                lastUpdated => 1119156590,
        },

    'default value label' => {
        message => q|Default Value|,
        lastUpdated => 1031514049
    },

    'default value description' => {
        message => q|Enter the default value (if any) for the field. If you have defined the possible values for
this field using a hash, then the default value has to be a key in that hash, and not a value. For Yes/No fields, enter "yes" to select "Yes" and "no" to select "No". For Date and Date/Time fields, enter an epoch date, or a date in YYYY-MM-DD HH:MM:SS, the ISO 9601 format with optional time|,
        lastUpdated => 1309814047,
    },

    'default value subtext' => {
        message => q|One per line.|,
        lastUpdated => 1206025720,
    },

    'subtext label' => {
        message => q|Subtext|,
        lastUpdated => 1031514049
    },

    'subtext description' => {
        message => q|An extension of the label, this is additional information such as a description of what should
go in the field or optional instructions for the field. It will be displayed below/after the form element.|,
        lastUpdated => 1224518799,
    },

    'pretext label' => {
        message => q|Pre-text|,
        lastUpdated => 1224518799,
    },

    'pretext description' => {
        message => q|An extra extension of the label, this is additional information such as a description of what should
go in the field or optional instructions for the field. It will be displayed above/before the form element.|,
        lastUpdated => 1224518799,
    },

    'fieldstatus hidden label' => {
        message => q|Hidden|,
        lastUpdated => 1031514049
    },
    
    'fieldstatus visible label' => {
        message => q|Visible|,
        lastUpdated => 1031514049
    },
    'fieldstatus editable label' => {
        message => q|Editable|,
        lastUpdated => 1031514049
    },
    'fieldstatus required label' => {
        message => q|Required|,
        lastUpdated => 1031514049
    },


    'field status label' => {
        message => q|Status|,
        lastUpdated => 1031514049
    },

    'field status description' => {
        message => q|Hidden fields will not be visible to the user. Visible fields can be seen by the user but not modified. Editable fields can be filled in by the user. Required fields must be filled in by the user. If you choose Hidden or Visible, be sure to fill in a Default Value.|,
        lastUpdated => 1119156590,
    },

    'width label' => {
        message => q|Width|,
        lastUpdated => 1104630516,
    },

    'width description' => {
        message => q|Set the width of textareas and HTMLareas in pixels.|,
        lastUpdated => 1104630516,
    },

    'size label' => {
        message => q|Size|,
        lastUpdated => 1104630516,
    },

    'size description' => {
        message => q|Set the size(width) of most fields in characters.|,
        lastUpdated => 1104630516,
    },

    'height label' => {
        message => q|Height|,
        lastUpdated => 1104630516,
    },

    'height description' => {
        message => q|Set the height of this field in pixels. Only used on Textareas and HTMLAreas.|,
        lastUpdated => 1153876588,
    },

    'height subtext' => {
        message => q|Optional for text area and HTML area.|,
        lastUpdated => 1104630516,
    },

    'vertical label' => {
        message => q|Vertical|,
        lastUpdated => 1104630516,
    },

    'vertical description' => {
        message => q|This property controls whether radio buttons and checklists are laid out horizontally or
vertically.|,
        lastUpdated => 1104630516,
    },

    'extras label' => {
        message => q|Extras|,
        lastUpdated => 1104630516,
    },

    'extras description' => {
        message => q|Here you can enter additional tag properties for the field tag. For instance
'class="myClass"'.|,
        lastUpdated => 1104630516,
    },

    'possible values label' => {
        message => q|Possible values|,
        lastUpdated => 1104630516,
    },

    'possible values description' => {
        message => q{This field is used for the list types (like Checkbox List and Select List).  Enter the values
you wish to appear, one per line. <br />
<br />If you want a different label for a value, the possible values list has to be
formatted as follows:
<pre>
   key1|value1
   key2|value2
   key3|value3
   ...
</pre>
Simply replace "key1"/"value1" with your own name/value pairs},
        lastUpdated => 1223372150,
    },

    'possible values subtext' => {
        message => q|One per line.|,
        lastUpdated => 1104630516,
    },

    'field in other thing label' => {
        message => q|Field In Other Thing|,
        lastUpdated => 1104630516,
    },

    'edit label' => {
        message => q|Edit|,
        lastUpdated => 1104630516,
    },

    'delete label' => {
        message => q|Delete|,
        lastUpdated => 1104630516,
    },

    'add label' => {
        message => q|Add|,
        lastUpdated => 1104630516,
    },

    'search label' => {
        message => q|Search|,
        lastUpdated => 1104630516,
    },

    'is required error' => {
        message => q| is required|,
        lastUpdated => 1104630516,
    },

    'thingy template label' => {
        message => q|Thingy Template|,
        lastUpdated => 1104630516,
    },

    'thingy template description' => {
        message => q|Choose a template for your thingy.|,
        lastUpdated => 1206026038,
    },

    'view thing template label' => {
        message => q|Thingy View Thing Template|,
        lastUpdated => 1104630516,
    },

    'edit thing template label' => {
        message => q|Thingy Edit Thing Template|,
        lastUpdated => 1104630516,
    },

    'search thing template label' => {
        message => q|Thingy Search Thing Template|,
        lastUpdated => 1104630516,
    },

    'canEditThings' => {
        message => q|Is true if the current user can view the Things that are defined for this Thingy Asset|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_json' => {
        message => q|JSON-encoded version of searchResult_loop so that you can access the data in Javascript|,
        lastUpdated => 1285094918,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'things_loop' => {
        message => q|A loop containing the Things that are defined for this Thingy Asset, with links to management
functions for those Things|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'thing_editIcon' => {
        message => q|An icon with a link to the edit screen for this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_editUrl' => {
        message => q|A link to the edit screen for this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_copyIcon' => {
        message => q|An icon with a link to copy this Thing|,
        lastUpdated => 0,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_copyUrl' => {
        message => q|A link to copy this Thing|,
        lastUpdated => 0,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_viewIcon' => {
        message => q|An icon with a link to default screen for this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_searchUrl' => {
        message => q|A link to the search screen for this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_addUrl' => {
        message => q|A link to the add screen for this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_deleteIcon' => {
        message => q|An icon with a link to delete this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_deleteUrl' => {
        message => q|A link to delete this Thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'thing_label' => {
        message => q|The label for this Thing|,
        lastUpdated => 1104630516,
    },

    'thing_id' => {
        message => q|The id of this Thing|,
        lastUpdated => 1104630516,
    },

    'manage_url' => {
        message => q|This Url will lead to a screen to manage the Things in this Thingy Asset.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'addThing_url' => {
        message => q|This Url leads to the screen to add a new Thing to this Thingy Asset.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'delete_url' => {
        message => q|The Url to delete the current thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'delete_confirm' => {
        message => q|This contains an onclick property for the delete link that adds a javascript confirmation|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'search_url' => {
        message => q|Url that leads to the search screen|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'add_url' => {
        message => q|Url to the add screen for this thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'editScreenTitle' => {
        message => q|The title for the edit screen|,
        lastUpdated => 1104630516,
    },

    'editInstructions' => {
        message => q|Instructions about editing this thing|,
        lastUpdated => 1104630516,
    },

    'error_loop' => {
        message => q|A loop containing error information, for instance if someone doesn't fill out a required
field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'error_message' => {
        message => q|An error message indicating what the user might have done wrong.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_loop' => {
        message => q|A loop containing the visible fields for this thing|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'listOfThings' => {
        message 	=> q|A loop containing a list of all the Things defined in this Thingy.|,
        lastUpdated => 0,
		context		=> q|A template variable|,
    },

    'canView' => {
        message 	=> q|A condition indicating whether the current user has the rights to view this thing.|,
        lastUpdated => 0,
		context		=> q|A template variable|,
    },

    'name' => {
        message 	=> q|The name of the Thing.|,
        lastUpdated => 0,
		context		=> q|A template variable|,
    },

    'isCurrent' => {
        message 	=> q|A condition indicating whether this Thing is the one that the user is currently interacting with.|,
        lastUpdated => 0,
		context		=> q|A template variable|,
    },

    'field_isHidden' => {
        message => q|A conditional indicating whether this field is supposed to be hidden.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_isRequired' => {
        message => q|A conditional indicating whether this field is required.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_isVisible' => {
        message => q|A conditional indicating whether this field is supposed to be visible but not editable.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_form' => {
        message => q|The form element for this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_name' => {
        message => q|The name of the form element for this field|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_type' => {
        message => q|The type (File, Text, etc) of this field|,
        lastUpdated => 1240968588,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_label' => {
        message => q|The label of this field|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_url' => {
        message => q|An optional url that this field should link to, used i.e. for fields in other things.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_value' => {
        message => q|The value of this field|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_pretext' => {
        message => q|An extra description of the field so that users know what to put in the field. To be
displayed above/before the form element.|,
        lastUpdated => 1224518799,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'field_subtext' => {
        message => q|A description of the field so that users know what to put in the field. To be displayed
below/after the form element.|,
        lastUpdated => 1224518799,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'form_start' => {
        message => q|The start tag of the form|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'form_submit' => {
        message => q|A form button to submit the form data.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'form_end' => {
        message => q|The end of the form|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'edit_url' => {
        message => q|Url to the current things edit screen.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'viewScreenTitle' => {
        message => q|The title for the view screen.  This is the concatenation of all values for fields which have View Screen Title set for this Thing.  If no fields are set, then the title is empty.|,
        lastUpdated => 1298915023,
    },

    'import_url' => {
        message => q|Url to import data into this Thing from a csv file|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'export_url' => {
        message => q|Url to export the all data in a thing into a csv file.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchScreenTitle' => {
        message => q|The title of the search screen|,
        lastUpdated => 1104630516,
    },

    'searchDescription' => {
        message => q|A description of the search screen.|,
        lastUpdated => 1104630516,
    },

    'searchFields_loop' => {
        message => q|A loop that contains the fields that are searchable|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'searchFields_label' => {
        message => q|The label of a searchable field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchFields_fieldId' => {
        message => q|The fieldId of a searchable field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchFields_form' => {
        message => q|A form element corresponding to this fields fieldType to search this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchFields_textForm' => {
        message => q|A text input to search this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchFields_is__fieldType__' => {
        message => q|A boolean indicating whether this field is of type __fieldType__. The first letter of __fieldType__ is always uppercase. Example: for a select box the value of &lt;tmpl_var searchFields_isSelectBox&gt; is true.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchFields_listType' => {
        message => q|A boolean indicating whether this field is a List type field.|,
        lastUpdated => 1277849256,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'displayInSearchFields_loop' => {
        message => q|A loop containing the fields that are displayed in the search results.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'displayInSearchFields_orderByUrl' => {
        message => q|Url to order the search results by this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'displayInSearchFields_label' => {
        message => q|The label of this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'displayInSearchFields_fieldId' => {
        message => q|The fieldId of this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_loop' => {
        message => q|A loop containing the search results.|,
        lastUpdated => 1206472126,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'searchResult_id' => {
        message => q|The id of a search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_view_url' => {
        message => q|Url to the view screen of this search result|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_edit_icon' => {
        message => q|Edit icon that links to the edit screen of this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_edit_url' => {
        message => q|Url to the edit screen of this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_delete_icon' => {
        message => q|Delete icon to delete this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_delete_url' => {
        message => q|Url to delete this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_copy_icon' => {
        message => q|Copy icon to copy this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'searchResult_copy_url' => {
        message => q|Url to copy this search result.|,
        lastUpdated => 1104630516,
    },

    'searchResult_field_loop' => {
        message => q|A loop containing the fields that are to be displayed for this search result.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_loop for the template help.|,
    },

    'field_id' => {
        message => q|The id of this field.|,
        lastUpdated => 1104630516,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'no field values message' => {
        message => q|Field does not have any values.|,
        lastUpdated => 1104630516,
    },

    'thingy asset template variables title' => {
        message => q|Thingy Asset Template Variables|,
        lastUpdated => 1164910794,
    },

    'thingy asset template variables body' => {
        message => q|Every asset provides a set of variables to most of its templates based on the internal asset properties.  Some of these variables may be useful, others may not.|,
        lastUpdated => 1164910794,
    },

    'other thing missing message' => {
        message => q|The Thing to which this field refers does not exist or has no table, or the field in it has been deleted.|,
        lastUpdated => 1231178860,
    },

    'no permission to edit' => {
        message => q|You do not have permissions to edit this Thing.|,
        lastUpdated => 1219424285,
    },

    'no permission to search' => {
        message => q|You do not have permissions to search this Thing.|,
        lastUpdated => 1219424285,
    },
    
    'thing must have fields' => {
        message => q|Error: You must assign fields to your new Thing.|,
        lastUpdated => 1219424285,
    },

    'back to thingy default view' => {
        message => q|Back to Thingy default view|,
        lastUpdated => 1227736916,
    },

    'view_url' => {
        message => q|The URL that will take the user back to the Thingy default view.|,
        lastUpdated => 1227737813,
        context => q|Description of a tmpl_var for the template help.|,
    },

    'other thing field missing message' => {
        message => q|The field from the other Thing does not exist.|,
        lastUpdated => 1231180362,
    },

    'Creating column headers' => {
        message => q|Creating column headers.|,
        lastUpdated => 1231180362,
        context => q|Status message in the Export Thingy progress bar.|,
    },

    'Writing data' => {
        message => q|Writing data.|,
        lastUpdated => 1231180362,
        context => q|Status message in the Export Thingy progress bar.|,
    },

    'Return to %s' => {
        message => q|Return to %s.|,
        lastUpdated => 1231180362,
        context => q|Status message in the Export Thingy progress bar. %s is the name of the Thing that is being exported.|,
    },

    'variables by label' => {
        message => q|In addition to the <b>field_loop</b>, field values may be directly accessed via their label.  Please check the documentation for the template plugin that you are using to handle odd characters like spaces or quotes in the label.|,
        lastUpdated => 1231180362,
        context => q|Template variable help for getViewThingData|,
    },

    'unique label' => {
        message => q|Unique|,
        lastUpdated => 1308006166,
        context => q|Label in the edit field screen.|,
    },

    'unique description' => {
        message => q|Is this a unique field?  In simple terms, values in unique fields can't have any duplicates in other rows.|,
        lastUpdated => 1308006162,
        context => q|Hoverhelp for edit field screen|,
    },

    'callerAssetId' => {
        message => q|When passed into the www_viewThingData, provides the assetId of the caller asset.  Used by RenderThingMacro.  See POD.|,
        lastUpdated => 0,
        context => q|Template variable help for www_viewThingData|,
    },

};

1;
